@@ -31,7 +31,7 @@ function getEnclosure(url, settings) {
         
         url = url.substring(0, i) + fragment;
         var fileName = decodeURIComponent(fragment.substring(0, fragment.search(/[\?&]/)));
-        finished(new Enclosure(fileName, new NetworkRequest(url)));
+        finished(new EnclosureResult(fileName, new NetworkRequest(url)));
     }
     catch(err) {
         error(err);
